@@ -41,7 +41,8 @@ class MultiStoreWithSqlAlchemyTestCase(TestCase):
         class Bazbot(DeclarativeBase):
     
             __tablename__ = "bazbots"
-            __mapper_args__ = {"extension": SqlAlchemyStoreExtension(lambda: store)}
+            __mapper_args__ = {"extension": SqlAlchemyStoreExtension()}
+            __stockpyle_store__ = property(lambda self: store)
     
             zap = Column(Integer, primary_key=True)
             foo = Column(Integer)
